@@ -9,8 +9,6 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 
-	"github.com/openshift/api/image/docker10"
-	"github.com/openshift/api/image/dockerpre012"
 	v1 "github.com/openshift/api/image/v1"
 	"github.com/openshift/library-go/pkg/image/reference"
 	newer "github.com/openshift/openshift-apiserver/pkg/image/apis/image"
@@ -22,8 +20,6 @@ var (
 )
 
 func init() {
-	docker10.AddToSchemeInCoreGroup(dockerImageScheme)
-	dockerpre012.AddToSchemeInCoreGroup(dockerImageScheme)
 	Install(dockerImageScheme)
 }
 
@@ -40,7 +36,7 @@ func Convert_image_Image_To_v1_Image(in *newer.Image, out *v1.Image, s conversio
 		gvString = "1.0"
 	}
 	if !strings.Contains(gvString, "/") {
-		gvString = "/" + gvString
+		gvString = "image.openshift.io/" + gvString
 	}
 
 	version, err := schema.ParseGroupVersion(gvString)
@@ -99,7 +95,7 @@ func Convert_v1_Image_To_image_Image(in *v1.Image, out *newer.Image, s conversio
 	}
 	if len(in.DockerImageMetadata.Raw) > 0 {
 		// TODO: add a way to default the expected kind and version of an object if not set
-		obj, err := dockerImageScheme.New(schema.GroupVersionKind{Version: version, Kind: "DockerImage"})
+		obj, err := dockerImageScheme.New(schema.GroupVersionKind{Group: "image.openshift.io", Version: version, Kind: "DockerImage"})
 		if err != nil {
 			return err
 		}
@@ -173,7 +169,7 @@ func Convert_v1_ImageStreamStatus_To_image_ImageStreamStatus(in *v1.ImageStreamS
 	out.DockerImageRepository = in.DockerImageRepository
 	out.PublicDockerImageRepository = in.PublicDockerImageRepository
 	out.Tags = make(map[string]newer.TagEventList)
-	return s.Convert(&in.Tags, &out.Tags, 0)
+	return Convert_v1_NamedTagEventListArray_to_api_TagEventListArray(&in.Tags, &out.Tags, s)
 }
 
 func Convert_image_ImageStreamStatus_To_v1_ImageStreamStatus(in *newer.ImageStreamStatus, out *v1.ImageStreamStatus, s conversion.Scope) error {
@@ -189,16 +185,60 @@ func Convert_image_ImageStreamStatus_To_v1_ImageStreamStatus(in *newer.ImageStre
 		}
 	}
 	out.Tags = make([]v1.NamedTagEventList, 0, 0)
-	return s.Convert(&in.Tags, &out.Tags, 0)
+	return Convert_image_TagEventListArray_to_v1_NamedTagEventListArray(&in.Tags, &out.Tags, s)
+}
+
+func Convert_image_TagEventConditionArray_to_v1_TagEventConditionArray(in *[]newer.TagEventCondition, out *[]v1.TagEventCondition, s conversion.Scope) error {
+	for _, o := range *in {
+		n := v1.TagEventCondition{}
+		if err := Convert_image_TagEventCondition_To_v1_TagEventCondition(&o, &n, s); err != nil {
+			return err
+		}
+		*out = append(*out, n)
+	}
+	return nil
+}
+
+func Convert_v1_TagEventConditionArray_to_image_TagEventConditionArray(in *[]v1.TagEventCondition, out *[]newer.TagEventCondition, s conversion.Scope) error {
+	for _, o := range *in {
+		n := newer.TagEventCondition{}
+		if err := Convert_v1_TagEventCondition_To_image_TagEventCondition(&o, &n, s); err != nil {
+			return err
+		}
+		*out = append(*out, n)
+	}
+	return nil
+}
+
+func Convert_image_TagEventArray_to_v1_TagEventArray(in *[]newer.TagEvent, out *[]v1.TagEvent, s conversion.Scope) error {
+	for _, o := range *in {
+		n := v1.TagEvent{}
+		if err := Convert_image_TagEvent_To_v1_TagEvent(&o, &n, s); err != nil {
+			return err
+		}
+		*out = append(*out, n)
+	}
+	return nil
+}
+
+func Convert_v1_TagEventArray_to_image_TagEventArray(in *[]v1.TagEvent, out *[]newer.TagEvent, s conversion.Scope) error {
+	for _, o := range *in {
+		n := newer.TagEvent{}
+		if err := Convert_v1_TagEvent_To_image_TagEvent(&o, &n, s); err != nil {
+			return err
+		}
+		*out = append(*out, n)
+	}
+	return nil
 }
 
 func Convert_v1_NamedTagEventListArray_to_api_TagEventListArray(in *[]v1.NamedTagEventList, out *map[string]newer.TagEventList, s conversion.Scope) error {
 	for _, curr := range *in {
 		newTagEventList := newer.TagEventList{}
-		if err := s.Convert(&curr.Conditions, &newTagEventList.Conditions, 0); err != nil {
+		if err := Convert_v1_TagEventConditionArray_to_image_TagEventConditionArray(&curr.Conditions, &newTagEventList.Conditions, s); err != nil {
 			return err
 		}
-		if err := s.Convert(&curr.Items, &newTagEventList.Items, 0); err != nil {
+		if err := Convert_v1_TagEventArray_to_image_TagEventArray(&curr.Items, &newTagEventList.Items, s); err != nil {
 			return err
 		}
 		(*out)[curr.Tag] = newTagEventList
@@ -216,10 +256,10 @@ func Convert_image_TagEventListArray_to_v1_NamedTagEventListArray(in *map[string
 	for _, key := range allKeys {
 		newTagEventList := (*in)[key]
 		oldTagEventList := &v1.NamedTagEventList{Tag: key}
-		if err := s.Convert(&newTagEventList.Conditions, &oldTagEventList.Conditions, 0); err != nil {
+		if err := Convert_image_TagEventConditionArray_to_v1_TagEventConditionArray(&newTagEventList.Conditions, &oldTagEventList.Conditions, s); err != nil {
 			return err
 		}
-		if err := s.Convert(&newTagEventList.Items, &oldTagEventList.Items, 0); err != nil {
+		if err := Convert_image_TagEventArray_to_v1_TagEventArray(&newTagEventList.Items, &oldTagEventList.Items, s); err != nil {
 			return err
 		}
 
@@ -258,6 +298,26 @@ func Convert_image_TagReferenceMap_to_v1_TagReferenceArray(in *map[string]newer.
 }
 
 func AddConversionFuncs(s *runtime.Scheme) error {
+	if err := s.AddConversionFunc((*[]newer.TagEventCondition)(nil), (*[]v1.TagEventCondition)(nil), func(a, b interface{}, scope conversion.Scope) error {
+		return Convert_image_TagEventConditionArray_to_v1_TagEventConditionArray(a.(*[]newer.TagEventCondition), b.(*[]v1.TagEventCondition), scope)
+	}); err != nil {
+		return err
+	}
+	if err := s.AddConversionFunc((*[]v1.TagEventCondition)(nil), (*[]newer.TagEventCondition)(nil), func(a, b interface{}, scope conversion.Scope) error {
+		return Convert_v1_TagEventConditionArray_to_image_TagEventConditionArray(a.(*[]v1.TagEventCondition), b.(*[]newer.TagEventCondition), scope)
+	}); err != nil {
+		return err
+	}
+	if err := s.AddConversionFunc((*[]newer.TagEvent)(nil), (*[]v1.TagEvent)(nil), func(a, b interface{}, scope conversion.Scope) error {
+		return Convert_image_TagEventArray_to_v1_TagEventArray(a.(*[]newer.TagEvent), b.(*[]v1.TagEvent), scope)
+	}); err != nil {
+		return err
+	}
+	if err := s.AddConversionFunc((*[]v1.TagEvent)(nil), (*[]newer.TagEvent)(nil), func(a, b interface{}, scope conversion.Scope) error {
+		return Convert_v1_TagEventArray_to_image_TagEventArray(a.(*[]v1.TagEvent), b.(*[]newer.TagEvent), scope)
+	}); err != nil {
+		return err
+	}
 	if err := s.AddConversionFunc((*[]v1.NamedTagEventList)(nil), (*map[string]newer.TagEventList)(nil), func(a, b interface{}, scope conversion.Scope) error {
 		return Convert_v1_NamedTagEventListArray_to_api_TagEventListArray(a.(*[]v1.NamedTagEventList), b.(*map[string]newer.TagEventList), scope)
 	}); err != nil {
@@ -278,7 +338,6 @@ func AddConversionFuncs(s *runtime.Scheme) error {
 	}); err != nil {
 		return err
 	}
-
 	return nil
 }
 
